BrainStat : A toolbox for statistical analysis of neuroimaging data
===================================================================

.. image:: https://img.shields.io/badge/License-BSD%203--Clause-blue.svg
    :target: https://opensource.org/licenses/BSD-3-Clause
.. image:: https://github.com/MICA-MNI/BrainStat/actions/workflows/python_unittests.yml/badge.svg
    :target: https://github.com/MICA-MNI/BrainStat/actions/workflows/python_unittests.yml
.. image:: https://github.com/MICA-MNI/BrainStat/actions/workflows/MATLAB_unittests.yml/badge.svg
    :target: https://github.com/MICA-MNI/BrainStat/actions/workflows/MATLAB_unittests.yml 
.. image:: https://readthedocs.org/projects/brainstat/badge/?version=master&style=plastic
    :target: https://brainstat.readthedocs.io/en/latest/
.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black
.. image:: https://www.mathworks.com/matlabcentral/images/matlab-file-exchange.svg
    :target: https://www.mathworks.com/matlabcentral/fileexchange/89827-brainstat

Welcome to BrainStat's documentation!

BrainStat is a toolbox for the statistical analysis and context decoding of
neuroimaging data. It implements both univariate and multivariate linear models
and interfaces with the BigBrain Atlas, Allen Human Brain Atlas and Nimare
databases. BrainStat flexibly handles common surface, volume, and parcel level
data formats, and provides a series of interactive visualization functions. The
toolbox has been implemented in both Python and MATLAB, the two most widely
adopted programming languages in the neuroimaging and neuroinformatics
communities. It is openly available, and documented `here
<https://brainstat.readthedocs.io/>`_. 

.. image:: https://github.com/MICA-LAB/BrainStat/blob/master/docs/figures/brainstat_logo_bw.png?raw=true

..
    For some reason referencing the BrainStat image locally doesn't work, so
    just linking to the image on Github instead. 

Developers
----------
.. |seyma_s|   unicode:: U+015E .. CEDILLA S

- Reinder Vos de Wael - MICA Lab, Montreal Neurological Institute
- |seyma_s|\ eyma Bayrak - Max Planck Institute for Human Cognitive and Brain Sciences 
- Oualid Benkarim - MICA Lab, Montreal Neurological Institute
- Sara Lariviere - MICA Lab, Montreal Neurological Institute
- Raul Cruces - MICA Lab, Montreal Neurological Institute
- Peer Herholz - Montreal Neurological Institute 
- Seok-Jun Hong - Sungkyunkwan University
- Sofie Valk - Max Planck Institute for Human Cognitive and Brain Sciences
- Boris Bernhardt - Montreal Neurological Institute 


License
-------

The BrainStat source code is available under the `BSD (3-Clause) license
<https://github.com/MICA-LAB/BrainStat/blob/master/LICENSE>`_.


Support
-------

If you have problems installing the software or questions about usage and
documentation, or something else related to BrainStat, you can post to the
`Issues <https://github.com/MICA-MNI/BrainStat/issues>`_ section of our repository.
